# react-native-svg-flagkit

react-native-svg-flagkit provides 250 flags to easily use in react-native.  
Assets are all from [FlagKit](https://github.com/madebybowtie/FlagKit).  
Inspired from [FlagKit](https://github.com/madebybowtie/FlagKit) & [react-native-svg](https://github.com/react-native-community/react-native-svg) & [svgr](https://github.com/smooth-code/svgr).

## Installation  

```
npm install --save react-native-svg-flagkit
```

react-native-svg-flagkit depends on [react-native-svg](https://github.com/react-native-community/react-native-svg).

```
react-native link react-native-svg
```

## Usage
```javascript
import { Flag } from 'react-native-svg-flagkit'

export default class App extends Component {
  render() {
    return (
      <View>
        <Flag 
            id={'TW'}
        />
        <Flag 
            id={'US'}
            size={0.2}
        />
        <Flag
            id={'JP'}
            width={100}
            height={100}
        />
      </View>
    );
  }
}

```

## Props

| Prop | Type | Default | Note |
|---|---|---|---|
| `size` | `number` | 1 | scale from default with, height
| `width` | `number` | 210 | SVG or Image width
| `height` | `number` | 150 | SVG or Image width
| `onPress` | `function` | | Press flag event

## Run example

```bash
git clone git@github.com:jackmew/react-native-svg-flagkit.git
cd example
npm install
```

## Run react-native-svg-flatkit/example/TestFlagKit.js

<div align="center">
    <img src="https://github.com/jackmew/react-native-svg-flagkit/blob/master/screenshot/flagKitDemo.png?raw=true" 
    height="609" width="281"
    />
</div>


## Todo
- [ ] Square Flag
- [ ] Circle Flag

## Flags

Due to there is a [react-native-svg Mask Component issue](https://github.com/react-native-community/react-native-svg/issues/273). 
There are some svg component is not available currently.   
When you use Flag component, it will automatically to use PNG to replace SVG.  
The only problem is that when you try to scale PNG, it will be fuzzy.  

| Flag | Code | Region | SVG | PNG |
| :-------------: | :-------------: | :-------------: | :-------------: | ------------- |
| <img src='PNG/AD@2x.png?raw=true' width='21' height='15'> | AD | Andorra                  |   ✅       |	✅		|
| <img src='PNG/AE@2x.png?raw=true' width='21' height='15'> | AE | United Arab Emirates     |   ✅       |	✅		|
| <img src='PNG/AF@2x.png?raw=true' width='21' height='15'> | AF | Afghanistan              |   ✅       |	✅		|
| <img src='PNG/AG@2x.png?raw=true' width='21' height='15'> | AG | Antigua & Barbuda        |   ❌      |	✅		|
| <img src='PNG/AI@2x.png?raw=true' width='21' height='15'> | AI | Anguilla                 |   ❌       |	✅		|
| <img src='PNG/AL@2x.png?raw=true' width='21' height='15'> | AL | Albania                  |   ✅       |	✅		|
| <img src='PNG/AM@2x.png?raw=true' width='21' height='15'> | AM | Armenia                  |   ✅       |	✅		|
| <img src='PNG/AO@2x.png?raw=true' width='21' height='15'> | AO | Angola                   |   ✅       |	✅		|
| <img src='PNG/AR@2x.png?raw=true' width='21' height='15'> | AR | Argentina                |   ✅       |	✅		|
| <img src='PNG/AS@2x.png?raw=true' width='21' height='15'> | AS | American Samoa           |   ✅       |	✅		|
| <img src='PNG/AT@2x.png?raw=true' width='21' height='15'> | AT | Austria                  |   ✅       |	✅		|
| <img src='PNG/AU@2x.png?raw=true' width='21' height='15'> | AU | Australia                |   ✅       |	✅		|
| <img src='PNG/AW@2x.png?raw=true' width='21' height='15'> | AW | Aruba                    |   ✅       |	✅		|
| <img src='PNG/AX@2x.png?raw=true' width='21' height='15'> | AX | Åland Islands            |   ✅       |	✅		|
| <img src='PNG/AZ@2x.png?raw=true' width='21' height='15'> | AZ | Azerbaijan               |   ✅       |	✅		|
| <img src='PNG/BA@2x.png?raw=true' width='21' height='15'> | BA | Bosnia & Herzegovina     |   ✅       |	✅		|
| <img src='PNG/BB@2x.png?raw=true' width='21' height='15'> | BB | Barbados                 |   ✅       |	✅		|
| <img src='PNG/BD@2x.png?raw=true' width='21' height='15'> | BD | Bangladesh               |   ✅       |	✅		|
| <img src='PNG/BE@2x.png?raw=true' width='21' height='15'> | BE | Belgium                  |   ✅       |	✅		|
| <img src='PNG/BF@2x.png?raw=true' width='21' height='15'> | BF | Burkina Faso             |   ✅       |	✅		|
| <img src='PNG/BG@2x.png?raw=true' width='21' height='15'> | BG | Bulgaria                 |   ✅       |	✅		|
| <img src='PNG/BH@2x.png?raw=true' width='21' height='15'> | BH | Bahrain                  |   ✅       |	✅		|
| <img src='PNG/BI@2x.png?raw=true' width='21' height='15'> | BI | Burundi                  |   ✅       |	✅		|
| <img src='PNG/BJ@2x.png?raw=true' width='21' height='15'> | BJ | Benin                    |   ✅       |	✅		|
| <img src='PNG/BL@2x.png?raw=true' width='21' height='15'> | BL | St. Barthélemy           |   ❌       |	✅		|
| <img src='PNG/BM@2x.png?raw=true' width='21' height='15'> | BM | Bermuda                  |   ❌       |	✅		|
| <img src='PNG/BN@2x.png?raw=true' width='21' height='15'> | BN | Brunei                   |   ✅       |	✅		|
| <img src='PNG/BO@2x.png?raw=true' width='21' height='15'> | BO | Bolivia                  |   ✅       |	✅		|
| <img src='PNG/BR@2x.png?raw=true' width='21' height='15'> | BR | Brazil                   |   ❌       |	✅		|
| <img src='PNG/BS@2x.png?raw=true' width='21' height='15'> | BS | Bahamas                  |   ✅       |	✅		|
| <img src='PNG/BT@2x.png?raw=true' width='21' height='15'> | BT | Bhutan                   |   ✅       |	✅		|
| <img src='PNG/BV@2x.png?raw=true' width='21' height='15'> | BV | Bouvet Island            |   ✅       |	✅		|
| <img src='PNG/BW@2x.png?raw=true' width='21' height='15'> | BW | Botswana                 |   ✅       |	✅		|
| <img src='PNG/BY@2x.png?raw=true' width='21' height='15'> | BY | Belarus                  |   ✅       |	✅		|
| <img src='PNG/BZ@2x.png?raw=true' width='21' height='15'> | BZ | Belize                   |   ✅       |	✅		|
| <img src='PNG/CA@2x.png?raw=true' width='21' height='15'> | CA | Canada                   |   ✅       |	✅		|
| <img src='PNG/CC@2x.png?raw=true' width='21' height='15'> | CC | Cocos (Keeling) Islands  |   ✅       |	✅		|
| <img src='PNG/CD@2x.png?raw=true' width='21' height='15'> | CD | Congo - Kinshasa         |   ✅       |	✅		|
| <img src='PNG/CF@2x.png?raw=true' width='21' height='15'> | CF | Central African Republic |   ✅       |	✅		|
| <img src='PNG/CG@2x.png?raw=true' width='21' height='15'> | CG | Congo - Brazzaville      |   ✅       |	✅		|
| <img src='PNG/CH@2x.png?raw=true' width='21' height='15'> | CH | Switzerland              |   ✅       |	✅		|
| <img src='PNG/CI@2x.png?raw=true' width='21' height='15'> | CI | Côte d’Ivoire            |   ✅       |	✅		|
| <img src='PNG/CK@2x.png?raw=true' width='21' height='15'> | CK | Cook Islands             |   ✅       |	✅		|
| <img src='PNG/CL@2x.png?raw=true' width='21' height='15'> | CL | Chile                    |   ✅       |	✅		|
| <img src='PNG/CM@2x.png?raw=true' width='21' height='15'> | CM | Cameroon                 |   ✅       |	✅		|
| <img src='PNG/CN@2x.png?raw=true' width='21' height='15'> | CN | China                    |   ✅       |	✅		|
| <img src='PNG/CO@2x.png?raw=true' width='21' height='15'> | CO | Colombia                 |   ✅       |	✅		|
| <img src='PNG/CR@2x.png?raw=true' width='21' height='15'> | CR | Costa Rica               |   ✅       |	✅		|
| <img src='PNG/CU@2x.png?raw=true' width='21' height='15'> | CU | Cuba                     |   ✅       |	✅		|
| <img src='PNG/CV@2x.png?raw=true' width='21' height='15'> | CV | Cape Verde               |   ✅       |	✅		|
| <img src='PNG/CW@2x.png?raw=true' width='21' height='15'> | CW | Curaçao                  |   ✅       |	✅		|
| <img src='PNG/CX@2x.png?raw=true' width='21' height='15'> | CX | Christmas Island         |   ✅       |	✅		|
| <img src='PNG/CY@2x.png?raw=true' width='21' height='15'> | CY | Cyprus                   |   ✅       |	✅		|
| <img src='PNG/CZ@2x.png?raw=true' width='21' height='15'> | CZ | Czech Republic           |   ✅       |	✅		|
| <img src='PNG/DE@2x.png?raw=true' width='21' height='15'> | DE | Germany                  |   ✅       |	✅		|
| <img src='PNG/DJ@2x.png?raw=true' width='21' height='15'> | DJ | Djibouti                 |   ✅       |	✅		|
| <img src='PNG/DK@2x.png?raw=true' width='21' height='15'> | DK | Denmark                  |   ✅       |	✅		|
| <img src='PNG/DM@2x.png?raw=true' width='21' height='15'> | DM | Dominica                 |   ✅       |	✅		|
| <img src='PNG/DO@2x.png?raw=true' width='21' height='15'> | DO | Dominican Republic       |   ✅       |	✅		|
| <img src='PNG/DZ@2x.png?raw=true' width='21' height='15'> | DZ | Algeria                  |   ✅       |	✅		|
| <img src='PNG/EC@2x.png?raw=true' width='21' height='15'> | EC | Ecuador                  |   ✅       |	✅		|
| <img src='PNG/EE@2x.png?raw=true' width='21' height='15'> | EE | Estonia                  |   ✅       |	✅		|
| <img src='PNG/EG@2x.png?raw=true' width='21' height='15'> | EG | Egypt                    |   ✅       |	✅		|
| <img src='PNG/ER@2x.png?raw=true' width='21' height='15'> | ER | Eritrea                  |   ✅       |	✅		|
| <img src='PNG/ES@2x.png?raw=true' width='21' height='15'> | ES | Spain                    |   ✅       |	✅		|
| <img src='PNG/ET@2x.png?raw=true' width='21' height='15'> | ET | Ethiopia                 |   ✅       |	✅		|
| <img src='PNG/EU@2x.png?raw=true' width='21' height='15'> | EU | European Union           |   ✅       |	✅		|
| <img src='PNG/FI@2x.png?raw=true' width='21' height='15'> | FI | Finland                  |   ✅       |	✅		|
| <img src='PNG/FJ@2x.png?raw=true' width='21' height='15'> | FJ | Fiji                     |   ❌       |	✅		|
| <img src='PNG/FK@2x.png?raw=true' width='21' height='15'> | FK | Falkland Islands         |   ❌      |	✅		|
| <img src='PNG/FM@2x.png?raw=true' width='21' height='15'> | FM | Micronesia               |   ✅       |	✅		|
| <img src='PNG/FO@2x.png?raw=true' width='21' height='15'> | FO | Faroe Islands            |   ✅       |	✅		|
| <img src='PNG/FR@2x.png?raw=true' width='21' height='15'> | FR | France                   |   ✅       |	✅		|
| <img src='PNG/GA@2x.png?raw=true' width='21' height='15'> | GA | Gabon                    |   ✅       |	✅		|
| <img src='PNG/GB@2x.png?raw=true' width='21' height='15'> | GB | United Kingdom           |   ✅       |	✅		|
| <img src='PNG/GB-ENG@2x.png?raw=true' width='21' height='15'> | GB-ENG | United Kingdom   |   ✅       |	✅		|
| <img src='PNG/GB-NIR@2x.png?raw=true' width='21' height='15'> | GB-NIR | United Kingdom   |   ❌       |	✅		|
| <img src='PNG/GB-SCT@2x.png?raw=true' width='21' height='15'> | GB-SCT | United Kingdom   |   ✅       |	✅		|
| <img src='PNG/GB-WLS@2x.png?raw=true' width='21' height='15'> | GB-WLS | United Kingdom   |   ✅       |	✅		|
| <img src='PNG/GB-ZET@2x.png?raw=true' width='21' height='15'> | GB-ZET | United Kingdom   |   ✅       |	✅		|
| <img src='PNG/GD@2x.png?raw=true' width='21' height='15'> | GD | Grenada                  |   ❌       |	✅		|
| <img src='PNG/GE@2x.png?raw=true' width='21' height='15'> | GE | Georgia                  |   ✅       |	✅		|
| <img src='PNG/GF@2x.png?raw=true' width='21' height='15'> | GF | French Guiana            |   ✅       |	✅		|
| <img src='PNG/GG@2x.png?raw=true' width='21' height='15'> | GG | Guernsey                 |   ✅       |	✅		|
| <img src='PNG/GH@2x.png?raw=true' width='21' height='15'> | GH | Ghana                    |   ✅       |	✅		|
| <img src='PNG/GI@2x.png?raw=true' width='21' height='15'> | GI | Gibraltar                |   ✅       |	✅		|
| <img src='PNG/GL@2x.png?raw=true' width='21' height='15'> | GL | Greenland                |   ❌       |	✅		|
| <img src='PNG/GM@2x.png?raw=true' width='21' height='15'> | GM | Gambia                   |   ✅       |	✅		|
| <img src='PNG/GN@2x.png?raw=true' width='21' height='15'> | GN | Guinea                   |   ✅       |	✅		|
| <img src='PNG/GP@2x.png?raw=true' width='21' height='15'> | GP | Guadeloupe               |   ✅       |	✅		|
| <img src='PNG/GQ@2x.png?raw=true' width='21' height='15'> | GQ | Equatorial Guinea        |   ✅       |	✅		|
| <img src='PNG/GR@2x.png?raw=true' width='21' height='15'> | GR | Greece                   |   ✅       |	✅		|
| <img src='PNG/GS@2x.png?raw=true' width='21' height='15'> | GS | So. Georgia & So. Sandwich Isl.  |   ❌       |	✅		|
| <img src='PNG/GT@2x.png?raw=true' width='21' height='15'> | GT | Guatemala                |   ✅       |	✅		|
| <img src='PNG/GU@2x.png?raw=true' width='21' height='15'> | GU | Guam                     |   ❌       |	✅		|
| <img src='PNG/GW@2x.png?raw=true' width='21' height='15'> | GW | Guinea-Bissau            |   ✅       |	✅		|
| <img src='PNG/GY@2x.png?raw=true' width='21' height='15'> | GY | Guyana                   |   ✅       |	✅		|
| <img src='PNG/HK@2x.png?raw=true' width='21' height='15'> | HK | Hong Kong (China)        |   ✅       |	✅		|
| <img src='PNG/HM@2x.png?raw=true' width='21' height='15'> | HM | Heard & McDonald Islands |   ✅       |	✅		|
| <img src='PNG/HN@2x.png?raw=true' width='21' height='15'> | HN | Honduras                 |   ✅       |	✅		|
| <img src='PNG/HR@2x.png?raw=true' width='21' height='15'> | HR | Croatia                  |   ✅       |	✅		|
| <img src='PNG/HT@2x.png?raw=true' width='21' height='15'> | HT | Haiti                    |   ❌       |	✅		|
| <img src='PNG/HU@2x.png?raw=true' width='21' height='15'> | HU | Hungary                  |   ✅       |	✅		|
| <img src='PNG/ID@2x.png?raw=true' width='21' height='15'> | ID | Indonesia                |   ✅       |	✅		|
| <img src='PNG/IE@2x.png?raw=true' width='21' height='15'> | IE | Ireland                  |   ✅       |	✅		|
| <img src='PNG/IL@2x.png?raw=true' width='21' height='15'> | IL | Israel                   |   ✅       |	✅		|
| <img src='PNG/IM@2x.png?raw=true' width='21' height='15'> | IM | Isle of Man              |   ✅       |	✅		|
| <img src='PNG/IN@2x.png?raw=true' width='21' height='15'> | IN | India                    |   ✅       |	✅		|
| <img src='PNG/IO@2x.png?raw=true' width='21' height='15'> | IO | British Indian Ocean Territory   |   ✅       |	✅		|
| <img src='PNG/IQ@2x.png?raw=true' width='21' height='15'> | IQ | Iraq                     |   ✅       |	✅		|
| <img src='PNG/IR@2x.png?raw=true' width='21' height='15'> | IR | Iran                     |   ✅       |	✅		|
| <img src='PNG/IS@2x.png?raw=true' width='21' height='15'> | IS | Iceland                  |   ✅       |	✅		|
| <img src='PNG/IT@2x.png?raw=true' width='21' height='15'> | IT | Italy                    |   ✅       |	✅		|
| <img src='PNG/JE@2x.png?raw=true' width='21' height='15'> | JE | Jersey                   |   ✅       |	✅		|
| <img src='PNG/JM@2x.png?raw=true' width='21' height='15'> | JM | Jamaica                  |   ✅       |	✅		|
| <img src='PNG/JO@2x.png?raw=true' width='21' height='15'> | JO | Jordan                   |   ✅       |	✅		|
| <img src='PNG/JP@2x.png?raw=true' width='21' height='15'> | JP | Japan                    |   ✅       |	✅		|
| <img src='PNG/KE@2x.png?raw=true' width='21' height='15'> | KE | Kenya                    |   ❌       |	✅		|
| <img src='PNG/KG@2x.png?raw=true' width='21' height='15'> | KG | Kyrgyzstan               |   ✅       |	✅		|
| <img src='PNG/KH@2x.png?raw=true' width='21' height='15'> | KH | Cambodia                 |   ✅       |	✅		|
| <img src='PNG/KI@2x.png?raw=true' width='21' height='15'> | KI | Kiribati                 |   ✅       |	✅		|
| <img src='PNG/KM@2x.png?raw=true' width='21' height='15'> | KM | Comoros                  |   ✅       |	✅		|
| <img src='PNG/KN@2x.png?raw=true' width='21' height='15'> | KN | St. Kitts & Nevis        |   ✅       |	✅		|
| <img src='PNG/KP@2x.png?raw=true' width='21' height='15'> | KP | North Korea              |   ✅       |	✅		|
| <img src='PNG/KR@2x.png?raw=true' width='21' height='15'> | KR | South Korea              |   ❌       |	✅		|
| <img src='PNG/KW@2x.png?raw=true' width='21' height='15'> | KW | Kuwait                   |   ✅       |	✅		|
| <img src='PNG/KY@2x.png?raw=true' width='21' height='15'> | KY | Cayman Islands           |   ❌       |	✅		|
| <img src='PNG/KZ@2x.png?raw=true' width='21' height='15'> | KZ | Kazakhstan               |   ✅       |	✅		|
| <img src='PNG/LA@2x.png?raw=true' width='21' height='15'> | LA | Laos                     |   ✅       |	✅		|
| <img src='PNG/LB@2x.png?raw=true' width='21' height='15'> | LB | Lebanon                  |   ✅       |	✅		|
| <img src='PNG/LC@2x.png?raw=true' width='21' height='15'> | LC | St. Lucia                |   ✅       |	✅		|
| <img src='PNG/LGBT@2x.png?raw=true' width='21' height='15'> | LGBT | Pride                |   ✅       |	✅		|
| <img src='PNG/LI@2x.png?raw=true' width='21' height='15'> | LI | Liechtenstein            |   ✅       |	✅		|
| <img src='PNG/LK@2x.png?raw=true' width='21' height='15'> | LK | Sri Lanka                |   ✅       |	✅		|
| <img src='PNG/LR@2x.png?raw=true' width='21' height='15'> | LR | Liberia                  |   ❌       |	✅		|
| <img src='PNG/LS@2x.png?raw=true' width='21' height='15'> | LS | Lesotho                  |   ✅       |	✅		|
| <img src='PNG/LT@2x.png?raw=true' width='21' height='15'> | LT | Lithuania                |   ✅       |	✅		|
| <img src='PNG/LU@2x.png?raw=true' width='21' height='15'> | LU | Luxembourg               |   ✅       |	✅		|
| <img src='PNG/LV@2x.png?raw=true' width='21' height='15'> | LV | Latvia                   |   ✅       |	✅		|
| <img src='PNG/LY@2x.png?raw=true' width='21' height='15'> | LY | Libya                    |   ✅       |	✅		|
| <img src='PNG/MA@2x.png?raw=true' width='21' height='15'> | MA | Morocco                  |   ✅       |	✅		|
| <img src='PNG/MC@2x.png?raw=true' width='21' height='15'> | MC | Monaco                   |   ✅       |	✅		|
| <img src='PNG/MD@2x.png?raw=true' width='21' height='15'> | MD | Moldova                  |   ❌       |	✅		|
| <img src='PNG/ME@2x.png?raw=true' width='21' height='15'> | ME | Montenegro               |   ✅       |	✅		|
| <img src='PNG/MF@2x.png?raw=true' width='21' height='15'> | MF | St. Martin               |   ✅       |	✅		|
| <img src='PNG/MG@2x.png?raw=true' width='21' height='15'> | MG | Madagascar               |   ✅       |	✅		|
| <img src='PNG/MH@2x.png?raw=true' width='21' height='15'> | MH | Marshall Islands         |   ✅       |	✅		|
| <img src='PNG/MK@2x.png?raw=true' width='21' height='15'> | MK | Macedonia                |   ✅       |	✅		|
| <img src='PNG/ML@2x.png?raw=true' width='21' height='15'> | ML | Mali                     |   ✅       |	✅		|
| <img src='PNG/MM@2x.png?raw=true' width='21' height='15'> | MM | Myanmar (Burma)          |   ✅       |	✅		|
| <img src='PNG/MN@2x.png?raw=true' width='21' height='15'> | MN | Mongolia                 |   ✅       |	✅		|
| <img src='PNG/MO@2x.png?raw=true' width='21' height='15'> | MO | Macau (China)            |   ✅       |	✅		|
| <img src='PNG/MP@2x.png?raw=true' width='21' height='15'> | MP | Northern Mariana Islands |   ✅       |	✅		|
| <img src='PNG/MQ@2x.png?raw=true' width='21' height='15'> | MQ | Martinique               |   ✅       |	✅		|
| <img src='PNG/MR@2x.png?raw=true' width='21' height='15'> | MR | Mauritania               |   ✅       |	✅		|
| <img src='PNG/MS@2x.png?raw=true' width='21' height='15'> | MS | Montserrat               |   ❌       |	✅		|
| <img src='PNG/MT@2x.png?raw=true' width='21' height='15'> | MT | Malta                    |   ❌       |	✅		|
| <img src='PNG/MU@2x.png?raw=true' width='21' height='15'> | MU | Mauritius                |   ✅       |	✅		|
| <img src='PNG/MV@2x.png?raw=true' width='21' height='15'> | MV | Maldives                 |   ✅       |	✅		|
| <img src='PNG/MW@2x.png?raw=true' width='21' height='15'> | MW | Malawi                   |   ✅       |	✅		|
| <img src='PNG/MX@2x.png?raw=true' width='21' height='15'> | MX | Mexico                   |   ✅       |	✅		|
| <img src='PNG/MY@2x.png?raw=true' width='21' height='15'> | MY | Malaysia                 |   ✅       |	✅		|
| <img src='PNG/MZ@2x.png?raw=true' width='21' height='15'> | MZ | Mozambique               |   ✅       |	✅		|
| <img src='PNG/NA@2x.png?raw=true' width='21' height='15'> | NA | Namibia                  |   ❌       |	✅		|
| <img src='PNG/NC@2x.png?raw=true' width='21' height='15'> | NC | New Caledonia            |   ✅       |	✅		|
| <img src='PNG/NE@2x.png?raw=true' width='21' height='15'> | NE | Niger                    |   ✅       |	✅		|
| <img src='PNG/NF@2x.png?raw=true' width='21' height='15'> | NF | Norfolk Island           |   ✅       |	✅		|
| <img src='PNG/NG@2x.png?raw=true' width='21' height='15'> | NG | Nigeria                  |   ✅       |	✅		|
| <img src='PNG/NI@2x.png?raw=true' width='21' height='15'> | NI | Nicaragua                |   ✅       |	✅		|
| <img src='PNG/NL@2x.png?raw=true' width='21' height='15'> | NL | Netherlands              |   ✅       |	✅		|
| <img src='PNG/NO@2x.png?raw=true' width='21' height='15'> | NO | Norway                   |   ✅       |	✅		|
| <img src='PNG/NP@2x.png?raw=true' width='21' height='15'> | NP | Nepal                    |   ❌       |	✅		|
| <img src='PNG/NR@2x.png?raw=true' width='21' height='15'> | NR | Nauru                    |   ✅       |	✅		|
| <img src='PNG/NU@2x.png?raw=true' width='21' height='15'> | NU | Niue                     |   ✅       |	✅		|
| <img src='PNG/NZ@2x.png?raw=true' width='21' height='15'> | NZ | New Zealand              |   ✅       |	✅		|
| <img src='PNG/OM@2x.png?raw=true' width='21' height='15'> | OM | Oman                     |   ✅       |	✅		|
| <img src='PNG/PA@2x.png?raw=true' width='21' height='15'> | PA | Panama                   |   ✅       |	✅		|
| <img src='PNG/PE@2x.png?raw=true' width='21' height='15'> | PE | Peru                     |   ❌       |	✅		|
| <img src='PNG/PF@2x.png?raw=true' width='21' height='15'> | PF | French Polynesia         |   ✅       |	✅		|
| <img src='PNG/PG@2x.png?raw=true' width='21' height='15'> | PG | Papua New Guinea         |   ✅       |	✅		|
| <img src='PNG/PH@2x.png?raw=true' width='21' height='15'> | PH | Philippines              |   ✅       |	✅		|
| <img src='PNG/PK@2x.png?raw=true' width='21' height='15'> | PK | Pakistan                 |   ❌       |	✅		|
| <img src='PNG/PL@2x.png?raw=true' width='21' height='15'> | PL | Poland                   |   ✅       |	✅		|
| <img src='PNG/PM@2x.png?raw=true' width='21' height='15'> | PM | St. Pierre & Miquelon    |   ❌       |	✅		|
| <img src='PNG/PN@2x.png?raw=true' width='21' height='15'> | PN | Pitcairn Islands         |   ❌       |	✅		|
| <img src='PNG/PR@2x.png?raw=true' width='21' height='15'> | PR | Puerto Rico              |   ✅       |	✅		|
| <img src='PNG/PS@2x.png?raw=true' width='21' height='15'> | PS | Palestinian Territories  |   ✅       |	✅		|
| <img src='PNG/PT@2x.png?raw=true' width='21' height='15'> | PT | Portugal                 |   ✅       |	✅		|
| <img src='PNG/PW@2x.png?raw=true' width='21' height='15'> | PW | Palau                    |   ✅       |	✅		|
| <img src='PNG/PY@2x.png?raw=true' width='21' height='15'> | PY | Paraguay                 |   ✅       |	✅		|
| <img src='PNG/QA@2x.png?raw=true' width='21' height='15'> | QA | Qatar                    |   ✅       |	✅		|
| <img src='PNG/RE@2x.png?raw=true' width='21' height='15'> | RE | Réunion                  |   ✅       |	✅		|
| <img src='PNG/RO@2x.png?raw=true' width='21' height='15'> | RO | Romania                  |   ✅       |	✅		|
| <img src='PNG/RS@2x.png?raw=true' width='21' height='15'> | RS | Serbia                   |   ❌       |	✅		|
| <img src='PNG/RU@2x.png?raw=true' width='21' height='15'> | RU | Russia                   |   ✅       |	✅		|
| <img src='PNG/RW@2x.png?raw=true' width='21' height='15'> | RW | Rwanda                   |   ✅       |	✅		|
| <img src='PNG/SA@2x.png?raw=true' width='21' height='15'> | SA | Saudi Arabia             |   ✅       |	✅		|
| <img src='PNG/SB@2x.png?raw=true' width='21' height='15'> | SB | Solomon Islands          |   ✅       |	✅		|
| <img src='PNG/SC@2x.png?raw=true' width='21' height='15'> | SC | Seychelles               |   ✅       |	✅		|
| <img src='PNG/SD@2x.png?raw=true' width='21' height='15'> | SD | Sudan                    |   ✅       |	✅		|
| <img src='PNG/SE@2x.png?raw=true' width='21' height='15'> | SE | Sweden                   |   ✅       |	✅		|
| <img src='PNG/SG@2x.png?raw=true' width='21' height='15'> | SG | Singapore                |   ✅       |	✅		|
| <img src='PNG/SH@2x.png?raw=true' width='21' height='15'> | SH | St. Helena               |   ❌       |	✅		|
| <img src='PNG/SI@2x.png?raw=true' width='21' height='15'> | SI | Slovenia                 |   ✅       |	✅		|
| <img src='PNG/SJ@2x.png?raw=true' width='21' height='15'> | SJ | Svalbard & Jan Mayen     |   ✅       |	✅		|
| <img src='PNG/SK@2x.png?raw=true' width='21' height='15'> | SK | Slovakia                 |   ❌       |	✅		|
| <img src='PNG/SL@2x.png?raw=true' width='21' height='15'> | SL | Sierra Leone             |   ✅       |	✅		|
| <img src='PNG/SM@2x.png?raw=true' width='21' height='15'> | SM | San Marino               |   ✅       |	✅		|
| <img src='PNG/SN@2x.png?raw=true' width='21' height='15'> | SN | Senegal                  |   ✅       |	✅		|
| <img src='PNG/SO@2x.png?raw=true' width='21' height='15'> | SO | Somalia                  |   ✅       |	✅		|
| <img src='PNG/SR@2x.png?raw=true' width='21' height='15'> | SR | Suriname                 |   ✅       |	✅		|
| <img src='PNG/SS@2x.png?raw=true' width='21' height='15'> | SS | South Sudan              |   ✅       |	✅		|
| <img src='PNG/ST@2x.png?raw=true' width='21' height='15'> | ST | São Tomé & Príncipe      |   ✅       |	✅		|
| <img src='PNG/SV@2x.png?raw=true' width='21' height='15'> | SV | El Salvador              |   ✅       |	✅		|
| <img src='PNG/SX@2x.png?raw=true' width='21' height='15'> | SX | Sint Maarten             |   ✅       |	✅		|
| <img src='PNG/SY@2x.png?raw=true' width='21' height='15'> | SY | Syria                    |   ✅       |	✅		|
| <img src='PNG/SZ@2x.png?raw=true' width='21' height='15'> | SZ | Swaziland                |   ❌       |	✅		|
| <img src='PNG/TC@2x.png?raw=true' width='21' height='15'> | TC | Turks & Caicos Islands   |   ✅       |	✅		|
| <img src='PNG/TD@2x.png?raw=true' width='21' height='15'> | TD | Chad                     |   ✅       |	✅		|
| <img src='PNG/TF@2x.png?raw=true' width='21' height='15'> | TF | French Southern Territories  |   ✅       |	✅		|
| <img src='PNG/TG@2x.png?raw=true' width='21' height='15'> | TG | Togo                     |   ✅       |	✅		|
| <img src='PNG/TH@2x.png?raw=true' width='21' height='15'> | TH | Thailand                 |   ✅       |	✅		|
| <img src='PNG/TJ@2x.png?raw=true' width='21' height='15'> | TJ | Tajikistan               |   ✅       |	✅		|
| <img src='PNG/TK@2x.png?raw=true' width='21' height='15'> | TK | Tokelau                  |   ✅       |	✅		|
| <img src='PNG/TL@2x.png?raw=true' width='21' height='15'> | TL | Timor-Leste              |   ✅       |	✅		|
| <img src='PNG/TM@2x.png?raw=true' width='21' height='15'> | TM | Turkmenistan             |   ❌       |	✅		|
| <img src='PNG/TN@2x.png?raw=true' width='21' height='15'> | TN | Tunisia                  |   ✅       |	✅		|
| <img src='PNG/TO@2x.png?raw=true' width='21' height='15'> | TO | Tonga                    |   ✅       |	✅		|
| <img src='PNG/TR@2x.png?raw=true' width='21' height='15'> | TR | Turkey                   |   ✅       |	✅		|
| <img src='PNG/TT@2x.png?raw=true' width='21' height='15'> | TT | Trinidad & Tobago        |   ✅       |	✅		|
| <img src='PNG/TV@2x.png?raw=true' width='21' height='15'> | TV | Tuvalu                   |   ✅       |	✅		|
| <img src='PNG/TW@2x.png?raw=true' width='21' height='15'> | TW | Taiwan                   |   ✅       |	✅		|
| <img src='PNG/TZ@2x.png?raw=true' width='21' height='15'> | TZ | Tanzania                 |   ✅       |	✅		|
| <img src='PNG/UA@2x.png?raw=true' width='21' height='15'> | UA | Ukraine                  |   ✅       |	✅		|
| <img src='PNG/UG@2x.png?raw=true' width='21' height='15'> | UG | Uganda                   |   ✅       |	✅		|
| <img src='PNG/UM@2x.png?raw=true' width='21' height='15'> | UM | U.S. Outlying Islands    |   ✅       |	✅		|
| <img src='PNG/US@2x.png?raw=true' width='21' height='15'> | US | United States            |   ✅       |	✅		|
| <img src='PNG/US-CA@2x.png?raw=true' width='21' height='15'> | US-CA | California         |   ❌       |	✅		|
| <img src='PNG/UY@2x.png?raw=true' width='21' height='15'> | UY | Uruguay                  |   ✅       |	✅		|
| <img src='PNG/UZ@2x.png?raw=true' width='21' height='15'> | UZ | Uzbekistan               |   ✅       |	✅		|
| <img src='PNG/VA@2x.png?raw=true' width='21' height='15'> | VA | Vatican City             |   ✅       |	✅		|
| <img src='PNG/VC@2x.png?raw=true' width='21' height='15'> | VC | St. Vincent & Grenadines |   ✅       |	✅		|
| <img src='PNG/VE@2x.png?raw=true' width='21' height='15'> | VE | Venezuela                |   ✅       |	✅		|
| <img src='PNG/VG@2x.png?raw=true' width='21' height='15'> | VG | British Virgin Islands   |   ✅       |	✅		|
| <img src='PNG/VI@2x.png?raw=true' width='21' height='15'> | VI | U.S. Virgin Islands      |   ❌       |	✅		|
| <img src='PNG/VN@2x.png?raw=true' width='21' height='15'> | VN | Vietnam                  |   ✅       |	✅		|
| <img src='PNG/VU@2x.png?raw=true' width='21' height='15'> | VU | Vanuatu                  |   ✅       |	✅		|
| <img src='PNG/WF@2x.png?raw=true' width='21' height='15'> | WF | Wallis & Futuna          |   ✅       |	✅		|
| <img src='PNG/WS@2x.png?raw=true' width='21' height='15'> | WS | Samoa                    |   ✅       |	✅		|
| <img src='PNG/XK@2x.png?raw=true' width='21' height='15'> | XK | Kosovo                   |   ✅       |	✅		|
| <img src='PNG/YE@2x.png?raw=true' width='21' height='15'> | YE | Yemen                    |   ✅       |	✅		|
| <img src='PNG/YT@2x.png?raw=true' width='21' height='15'> | YT | Mayotte                  |   ❌       |	✅		|
| <img src='PNG/ZA@2x.png?raw=true' width='21' height='15'> | ZA | South Africa             |   ✅       |	✅		|
| <img src='PNG/ZM@2x.png?raw=true' width='21' height='15'> | ZM | Zambia                   |   ✅       |	✅		|
| <img src='PNG/ZW@2x.png?raw=true' width='21' height='15'> | ZW | Zimbabwe                 |   ✅       |	✅		|